<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>AddFxContextMenu</name>
    <message>
        <source>Insert FX</source>
        <translation>Inserisci un Effetto</translation>
    </message>
    <message>
        <source>Add FX</source>
        <translation>Aggiungi un Effetto</translation>
    </message>
    <message>
        <source>Replace FX</source>
        <translation>Rimpiazza l&apos;Effetto</translation>
    </message>
    <message>
        <source>Insert </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddWordButton</name>
    <message>
        <source>Character</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add New Word for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdjustPaletteDialog</name>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Adatta il Livello Corrente a questa Palette</translation>
    </message>
    <message>
        <source>Tolerance</source>
        <translation>Tolleranza</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>CameraPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Ripristina il centro</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>&amp;Attiva</translation>
    </message>
</context>
<context>
    <name>CameraSettingsWidget</name>
    <message>
        <source>Width:</source>
        <translation type="vanished">Larghezza:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="vanished">Altezza:</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>XDpi:</source>
        <translation type="vanished">XDpi:</translation>
    </message>
    <message>
        <source>YDpi:</source>
        <translation type="vanished">YDpi:</translation>
    </message>
    <message>
        <source>Use Current Level Settings</source>
        <translation>Utilizzare Impostazioni Livello Corrente</translation>
    </message>
    <message>
        <source>Bad camera preset</source>
        <translation>Errore nel Preset della Camera</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
Possibly the preset file has been corrupted</source>
        <translation>%1 non sempbra essere un preset di camera corretto.
E&apos; possibile che il file sia corrotto.</translation>
    </message>
    <message>
        <source>Preset name</source>
        <translation>Nome predefinito</translation>
    </message>
    <message>
        <source>Enter the name for %1</source>
        <translation>Inserire il nome per %1</translation>
    </message>
    <message>
        <source>AR:</source>
        <translation type="vanished">AR:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force Squared Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error : Preset Name is Invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The preset name must not use &apos;,&apos;(comma).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished">&lt;custom&gt;</translation>
    </message>
    <message>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pixel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChannelHisto</name>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CleanupCameraSettingsWidget</name>
    <message>
        <source>Closest:</source>
        <translation type="vanished">Closest:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="vanished">E/O</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="vanished">Y</translation>
    </message>
    <message>
        <source>DPI:</source>
        <translation type="vanished">DPI:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Nome:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation type="vanished">Percorso:</translation>
    </message>
    <message>
        <source>Field settings</source>
        <translation type="vanished">Impostazioni dei Field</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>Resulting Level Info</source>
        <translation type="vanished">Informazioni sul Livello</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColumnPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Ripristina il centro</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">&amp;Apri il Sub-xsheet</translation>
    </message>
</context>
<context>
    <name>ComboHistoRGBLabel</name>
    <message>
        <source>R:%1 G:%2 B:%3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComboHistogram</name>
    <message>
        <source>Picked Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average Color (Ctrl + Drag)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">E/O</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>8bit (0-255)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16bit (0-65535)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.0-1.0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui</name>
    <message>
        <source>OK</source>
        <translation type="vanished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Annulla</translation>
    </message>
</context>
<context>
    <name>DVGui::CleanupColorField</name>
    <message>
        <source>Brightness:</source>
        <translation>Luminosità:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>Contrasto:</translation>
    </message>
    <message>
        <source>Color Threshold</source>
        <translation type="vanished">Soglia del Colore:</translation>
    </message>
    <message>
        <source>White Threshold</source>
        <translation type="vanished">Soglia del Bianco:</translation>
    </message>
    <message>
        <source>H Range</source>
        <translation>Intervallo di Tinta:</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Spessore della Linea:</translation>
    </message>
    <message>
        <source>Color Thres</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White Thres</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ColorField</name>
    <message>
        <source>R:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="unfinished">Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished">Corsivo</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished">Sottolineato</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="unfinished">Allinea a Sinistra</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="unfinished">Allinea al centro</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="unfinished">Allinea a Destra</translation>
    </message>
</context>
<context>
    <name>DVGui::FileField</name>
    <message>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
</context>
<context>
    <name>DVGui::HexColorNamesEditor</name>
    <message>
        <source>Hex Color Names Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Applica</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Main Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Auto-Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Color Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text or XML (*.txt *.xml);;Text files (*.txt);;XML files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex Color Names Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to merge with existing entries?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error importing color names XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Color Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files (*.xml);;Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error exporting color names XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="obsolete">Il nome di un file non può contenere i seguenti caratteri: /\:*?&quot;|.</translation>
    </message>
    <message>
        <source>A file name cannot contains any of the following characters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="obsolete">Toonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="obsolete">Toonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="unfinished">È possibile caricare solo i file TNZBAT.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Intervallo:</translation>
    </message>
    <message>
        <source>Output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ValidatedChoiceDialog</name>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Apply to All</source>
        <translation>Applica a Tutto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="vanished">Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Corsivo</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="vanished">Sottolineato</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="vanished">Allinea a Sinistra</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="vanished">Allinea al centro</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="vanished">Allinea a Destra</translation>
    </message>
</context>
<context>
    <name>EaseInOutSegmentPage</name>
    <message>
        <source>Ease In:</source>
        <translation>Ease In:</translation>
    </message>
    <message>
        <source>Ease Out:</source>
        <translation>Ease Out:</translation>
    </message>
</context>
<context>
    <name>EasyInputArea</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Attenzione</translation>
    </message>
    <message>
        <source>%1 is already registered</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileField</name>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
</context>
<context>
    <name>FileSegmentPage</name>
    <message>
        <source>File Path:</source>
        <translation>Percorso del File:</translation>
    </message>
    <message>
        <source>Column:</source>
        <translation>Colonna:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Unità:</translation>
    </message>
</context>
<context>
    <name>FlipConsole</name>
    <message>
        <source> FPS </source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Istantanea</translation>
    </message>
    <message>
        <source>Define Sub-camera</source>
        <translation>Definisci la Sotto-Camera</translation>
    </message>
    <message>
        <source>Background Colors</source>
        <translation>Colori del Fondale</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>Immagini per Secondo</translation>
    </message>
    <message>
        <source>Playback Controls</source>
        <translation>Riproduzione</translation>
    </message>
    <message>
        <source>Color Channels</source>
        <translation>Canali di Colore</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Imposta una Chiave</translation>
    </message>
    <message>
        <source>Histogram</source>
        <translation>Istogramma</translation>
    </message>
    <message>
        <source>&amp;Save Images</source>
        <translation>&amp;Salva le Immagini</translation>
    </message>
    <message>
        <source>&amp;Snapshot</source>
        <translation>&amp;Istantanea</translation>
    </message>
    <message>
        <source>&amp;Compare to Snapshot</source>
        <translation>&amp;Confronta con l&apos;Istantanea</translation>
    </message>
    <message>
        <source>&amp;Define Sub-camera</source>
        <translation>&amp;Defininisci la Sotto-Camera</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>&amp;Fondale Bianco</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>&amp;Fondale Nero</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>&amp;Fondale a Scacchiera</translation>
    </message>
    <message>
        <source>Set the playback frame rate</source>
        <translation>Imposta la Frequenza dei Fotogrammi per la Riproduzione</translation>
    </message>
    <message>
        <source>&amp;First Frame</source>
        <translation>&amp;Primo Fotogramma</translation>
    </message>
    <message>
        <source>&amp;Previous Frame</source>
        <translation>&amp;Fotogramma Precedente</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Ciclo Continuo</translation>
    </message>
    <message>
        <source>&amp;Next frame</source>
        <translation type="vanished">&amp;Prossimo Fotogramma</translation>
    </message>
    <message>
        <source>&amp;Last Frame</source>
        <translation>&amp;Ultimo Fotogramma</translation>
    </message>
    <message>
        <source>Red Channel</source>
        <translation>Canale Rosso</translation>
    </message>
    <message>
        <source>Red Channel in Grayscale</source>
        <translation>Canale Rosso in Scala di Grigi</translation>
    </message>
    <message>
        <source>Green Channel</source>
        <translation>Canale Verde</translation>
    </message>
    <message>
        <source>Green Channel in Grayscale</source>
        <translation>Canale Verde in Scala di Grigi</translation>
    </message>
    <message>
        <source>Blue Channel</source>
        <translation>Canale Blu</translation>
    </message>
    <message>
        <source>Blue Channel in Grayscale</source>
        <translation>Canale Blu in Scala di Grigi</translation>
    </message>
    <message>
        <source>Alpha Channel</source>
        <translation>Canale Alfa</translation>
    </message>
    <message>
        <source>&amp;Soundtrack </source>
        <translation>&amp;Colonna Sonora</translation>
    </message>
    <message>
        <source>&amp;Histogram</source>
        <translation>&amp;Istogramma</translation>
    </message>
    <message>
        <source> FPS	</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source> Frame  </source>
        <translation type="vanished">Fotogramma</translation>
    </message>
    <message>
        <source>Set the current frame</source>
        <translation>Imposta il Fotogramma Corrente</translation>
    </message>
    <message>
        <source>Drag to play the animation</source>
        <translation>Trascina per Riprodurre l&apos;Animazione</translation>
    </message>
    <message>
        <source>Define Loading Box</source>
        <translation>Definisci il Riquadro di Caricamento</translation>
    </message>
    <message>
        <source>Use Loading Box</source>
        <translation>Usa il Riquadro di Caricamento</translation>
    </message>
    <message>
        <source>&amp;Define Loading Box</source>
        <translation>&amp;Definisci il Riquadro di Caricamento</translation>
    </message>
    <message>
        <source>&amp;Use Loading Box</source>
        <translation>&amp;Usa il Riquadro di Caricamento</translation>
    </message>
    <message>
        <source>Display Areas as Filled</source>
        <translation>Mostra Zone come Riempite</translation>
    </message>
    <message>
        <source>&amp;Display Areas as Filled</source>
        <translation>&amp;Mostra Zone come Riempite</translation>
    </message>
    <message>
        <source>&amp;Locator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Viewer Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontParamField</name>
    <message>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrameNavigator</name>
    <message>
        <source>Previous Frame</source>
        <translation>Fotogramma Precedente</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>Fotogramma Successivo</translation>
    </message>
</context>
<context>
    <name>FunctionExpressionSegmentPage</name>
    <message>
        <source>Expression:</source>
        <translation>Espressione:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Unità:</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>C&apos;è un riferimento circolare nella definizione dell&apos;interpolazione.</translation>
    </message>
</context>
<context>
    <name>FunctionPanel</name>
    <message>
        <source>Link Handles</source>
        <translation>Collega le Maniglie</translation>
    </message>
    <message>
        <source>Unlink Handles</source>
        <translation>Scollega le Maniglie</translation>
    </message>
    <message>
        <source>Reset Handles</source>
        <translation>Ripristina le Maniglie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Imposta la Chiave</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>Attiva il Ciclo</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>Disattiva il Ciclo</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Interpolazione Lineare</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Interpolazione Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Interpolazione Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Interpolazione Ease In / Ease Out (%)</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Interpolazione Esponenziale</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Interpolazione tramite Espressione</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolazione tramite File</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Interpolazione Costante</translation>
    </message>
    <message>
        <source>Fit Selection</source>
        <translation>Adatta alla Selezione</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation>Adatta</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>Interpolazione tramite Forma Simile</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>Passo 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>Passo 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>Passo 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>Passo 4</translation>
    </message>
    <message>
        <source>Function Curves</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Based</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Curve Shape</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSegmentViewer</name>
    <message>
        <source>Linear</source>
        <translation>Lineare</translation>
    </message>
    <message>
        <source>Speed In / Speed Out</source>
        <translation>Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out</source>
        <translation>Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out %</source>
        <translation>Ease In / Ease Out %</translation>
    </message>
    <message>
        <source>Exponential</source>
        <translation>Exponenziale</translation>
    </message>
    <message>
        <source>Expression</source>
        <translation>Espressione</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Constant</source>
        <translation>Costante</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">Intervallo:</translation>
    </message>
    <message>
        <source>Interpolation:</source>
        <translation>Interpolazione:</translation>
    </message>
    <message>
        <source>Step:</source>
        <translation type="vanished">Passo:asso 2</translation>
    </message>
    <message>
        <source>Similar Shape</source>
        <translation>Forma Simile</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Applica</translation>
    </message>
    <message>
        <source>&lt; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> &gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ease%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Const</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Similar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>????</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link/Unlink Handles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSelection</name>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation type="unfinished">C&apos;è un riferimento circolare nella definizione dell&apos;interpolazione.</translation>
    </message>
</context>
<context>
    <name>FunctionSheet</name>
    <message>
        <source>Function Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSheetButtonArea</name>
    <message>
        <source>Toggle synchronizing zoom with xsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSheetCellViewer</name>
    <message>
        <source>Delete Key</source>
        <translation>Elimina la Chiave</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Imposta la Chiave</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Interpolazione Lineare</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Interpolazione Speed In / Speed Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Interpolazione Ease In / Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Interpolazione Ease In / Ease Out (%)</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Interpolazione tramite Espressione</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolazione tramite File</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Interpolazione Costante</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Interpolazione Esponenziale</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation type="vanished">Passo 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation type="vanished">Passo 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation type="vanished">Passo 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation type="vanished">Passo 4</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation type="unfinished">Attiva il Ciclo</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation type="unfinished">Disattiva il Ciclo</translation>
    </message>
    <message>
        <source>Show Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation type="unfinished">Interpolazione tramite Forma Simile</translation>
    </message>
</context>
<context>
    <name>FunctionSheetColumnHeadViewer</name>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionToolbar</name>
    <message>
        <source>Value</source>
        <translation>Valore</translation>
    </message>
    <message>
        <source>&amp;Function Editor Toggle</source>
        <translation type="vanished">&amp;Editor delle Funzioni</translation>
    </message>
    <message>
        <source>&amp;Open Function Curve Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeModel</name>
    <message>
        <source>Stage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plastic Skeleton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeView</name>
    <message>
        <source>Save Curve</source>
        <translation>Salva la Curva</translation>
    </message>
    <message>
        <source>Load Curve</source>
        <translation>Carica la Curva</translation>
    </message>
    <message>
        <source>Export Data</source>
        <translation>Esporta i dati</translation>
    </message>
    <message>
        <source>Show Animated Only</source>
        <translation>Mostra Solo quelle Animate</translation>
    </message>
    <message>
        <source>Show All</source>
        <translation>Mostrale Tutte</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxColumnPainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Disconnetti dall&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connetti all&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Incolla Aggiungendo</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">&amp;Apri il Sub-xsheet</translation>
    </message>
    <message>
        <source>&amp;Uncache Fx</source>
        <translation>&amp;Togli l&apos;Effetto dalla Cache</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>&amp;Metti  l&apos;Effetto in Cache</translation>
    </message>
</context>
<context>
    <name>FxOutputPainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>&amp;Attiva</translation>
    </message>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>&amp;Apri il Gruppo</translation>
    </message>
    <message>
        <source>&amp;Paste Replace</source>
        <translation>&amp;Incolla Rimpiazzando</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Incolla Aggiungendo</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Disconnetti dall&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connetti all&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Create Linked FX</source>
        <translation>&amp;Crea un Effetto Collegato</translation>
    </message>
    <message>
        <source>&amp;Unlink</source>
        <translation>&amp;Scollega</translation>
    </message>
    <message>
        <source>&amp;Make Macro FX</source>
        <translation>&amp;Crea un Effetto Macro</translation>
    </message>
    <message>
        <source>&amp;Explode Macro FX</source>
        <translation>&amp;Esplodi l&apos;Effetto Macro</translation>
    </message>
    <message>
        <source>&amp;Open Macro FX</source>
        <translation>&amp;Apri l&apos;Effetto macro</translation>
    </message>
    <message>
        <source>&amp;Save As Preset...</source>
        <translation>&amp;Salva come Effetto Predefinito</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
    <message>
        <source>&amp;Uncache FX</source>
        <translation>&amp;Togli l&apos;Effetto dalla Cache</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>&amp;Metti  l&apos;Effetto in Cache</translation>
    </message>
</context>
<context>
    <name>FxPalettePainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Disconnetti dall&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connetti all&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
</context>
<context>
    <name>FxPassThroughPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation type="unfinished">&amp;Incolla Aggiungendo</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">&amp;Anteprima</translation>
    </message>
</context>
<context>
    <name>FxSchematicLink</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>&amp;Paste Insert</source>
        <translation>&amp;Incolla Inserendo</translation>
    </message>
</context>
<context>
    <name>FxSchematicOutputNode</name>
    <message>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSchematicPassThroughNode</name>
    <message>
        <source> (Pass Through)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSchematicPort</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>&amp;Disconnetti dall&apos;Xsheet</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>&amp;Connetti all&apos;Xsheet</translation>
    </message>
</context>
<context>
    <name>FxSchematicScene</name>
    <message>
        <source>Cannot Paste Insert a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Non è possibile Incollare Inserendo una selezione di effetti disconnessi.
Seleziona i nodi Effetto ed i relativi collegamenti prima di copiare o tagliare la selezione che vuoi incollare.</translation>
    </message>
    <message>
        <source>Cannot Paste Add a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Non è possibile Incollare Aggiungendo una selezione di effetti disconnessi.
Seleziona i nodi Effetto ed i relativi collegamenti prima di copiare o tagliare la selezione che vuoi incollare.</translation>
    </message>
    <message>
        <source>Cannot Paste Replace a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Non è possibile Incollare Rimpiazzando una selezione di effetti disconnessi.
Seleziona i nodi Effetto ed i relativi collegamenti prima di copiare o tagliare la selezione che vuoi incollare.</translation>
    </message>
</context>
<context>
    <name>FxSchematicXSheetNode</name>
    <message>
        <source>XSheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSettings</name>
    <message>
        <source>&amp;Camera Preview</source>
        <translation>&amp;Anteprima di camera</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>&amp;Fondale Bianco</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>&amp;Fondale Nero</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>&amp;Fondale a Scacchiera</translation>
    </message>
    <message>
        <source> : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fx Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxXSheetPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>&amp;Incolla Aggiungendo</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Anteprima</translation>
    </message>
    <message>
        <source>XSheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GroupPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>&amp;Apri il Gruppo</translation>
    </message>
</context>
<context>
    <name>Histogram</name>
    <message>
        <source>Logarithmic Scale</source>
        <translation>Scala Logaritmica</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="unfinished">Valore</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoViewer</name>
    <message>
        <source>File Info</source>
        <translation>Informazioni sul File</translation>
    </message>
</context>
<context>
    <name>KeyframeNavigator</name>
    <message>
        <source>Previous Key</source>
        <translation>Chiave Precedente</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Imposta una Chiave</translation>
    </message>
    <message>
        <source>Next Key</source>
        <translation>Chiave Successiva</translation>
    </message>
</context>
<context>
    <name>LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">Il nome di un file non può contenere i seguenti caratteri: /\:*?&quot;|.</translation>
    </message>
</context>
<context>
    <name>MyPaintBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="obsolete">Colore Piatto</translation>
    </message>
</context>
<context>
    <name>NewWordDialog</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <source>Enter new word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageViewer</name>
    <message>
        <source>Toggle Link to Studio Palette</source>
        <translation type="vanished">Attiva/Disattiva il Collegamento con la Palette di Studio</translation>
    </message>
    <message>
        <source>Remove Reference to Studio Palette</source>
        <translation type="vanished">Elimina il Riferimento alla Palette di Studio</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="vanished">Nuovo Stile</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="vanished">Nuova Pagina</translation>
    </message>
</context>
<context>
    <name>PaletteViewer</name>
    <message>
        <source>&amp;Save Palette As</source>
        <translation>&amp;Salva la Palette Come</translation>
    </message>
    <message>
        <source>&amp;Save Palette</source>
        <translation>&amp;Salva la Palette</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails View</source>
        <translation>&amp;Visualizzazione a Piccole Icone</translation>
    </message>
    <message>
        <source>&amp;Large Thumbnails View</source>
        <translation>&amp;Visualizzazione a Grandi Icone</translation>
    </message>
    <message>
        <source>&amp;List View</source>
        <translation>&amp;Visualizzazione a Lista</translation>
    </message>
    <message>
        <source>&amp;New Page</source>
        <translation>&amp;Nuova Pagina</translation>
    </message>
    <message>
        <source>&amp;New Style</source>
        <translation>&amp;Nuovo Stile</translation>
    </message>
    <message>
        <source>&amp;Move Palette</source>
        <translation>&amp;Sposta la Palette</translation>
    </message>
    <message>
        <source>Color Model: </source>
        <translation type="vanished">Modello di Colore:</translation>
    </message>
    <message>
        <source>&amp;Palette Gizmo</source>
        <translation>&amp;Palette Gizmo</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nuova Pagina</translation>
    </message>
    <message>
        <source>Delete Page</source>
        <translation>Elimina la Pagina</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <source>Level Palette: </source>
        <translation>Palette del Livello:</translation>
    </message>
    <message>
        <source>Cleanup Palette</source>
        <translation>Palette di Cleanup</translation>
    </message>
    <message>
        <source>Studio Palette</source>
        <translation>Palette di Studio</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails With Name View</source>
        <translation type="vanished">Icone piccole con Nome Visualizzato</translation>
    </message>
    <message>
        <source>Lock Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Lock Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Medium Thumbnails View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StudioPalette Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     (Color Model: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide New Style Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show New Style Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Toolbar Below Styles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Toolbar Above Styles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PaletteViewerGUI::PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="unfinished">Nuovo Stile</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="unfinished">Nuova Pagina</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> + </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PalettesScanPopup</name>
    <message>
        <source>Search for Palettes</source>
        <translation>Ricerca le Palette</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&lt;files&gt;</source>
        <translation>&lt;files&gt;</translation>
    </message>
    <message>
        <source>Failed to import palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParamViewer</name>
    <message>
        <source>Swatch Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParamsPageSet</name>
    <message>
        <source>View help page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PegbarPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Ripristina il Centro</translation>
    </message>
</context>
<context>
    <name>PlaneViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PointParamField</name>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">E/O</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Information</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Critico</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <source>Styles you are going to delete are used to paint lines and areas in the animation level.
</source>
        <translation>Gli stili che stai per cancellare sono usati per colorare linee e aree del livello di animazione.</translation>
    </message>
    <message>
        <source>How do you want to proceed?</source>
        <translation>Come vuoi procedere?</translation>
    </message>
    <message>
        <source>Delete Styles Only</source>
        <translation>Elimina solo gli Stili</translation>
    </message>
    <message>
        <source>Delete Styles, Lines and Areas</source>
        <translation>Elimina gli Stili, le Linee e le Aree</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Cannot premultiply the selected file.</source>
        <translation>Non è possibile premoltiplicare il file selezionato.</translation>
    </message>
    <message>
        <source>Cannot premultiply a vector-based level.</source>
        <translation>Non è possibile premoltiplicareun livello vettoriale.</translation>
    </message>
    <message>
        <source>Level %1 premultiplied.</source>
        <translation>Il Livello %1 è stato premoltiplicato.</translation>
    </message>
    <message>
        <source>Frame %1 : conversion failed!</source>
        <translation>Fotogramma %1: conversione fallita.</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="vanished">Palette</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Salva</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="vanished">Scarta</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">No</translation>
    </message>
    <message>
        <source>Stage Schematic</source>
        <translation>Diagramma di Scena</translation>
    </message>
    <message>
        <source>FX Schematic</source>
        <translation>Diagramma degli Effetti</translation>
    </message>
    <message>
        <source>Fx Schematic</source>
        <translation type="vanished">Diagramma degli Effetti</translation>
    </message>
    <message>
        <source>Save Motion Path</source>
        <translation>Salva la Traiettoria di Movimento</translation>
    </message>
    <message>
        <source>Motion Path files (*.mpath)</source>
        <translation>File della Traiettoria di Movimento (*.mpath)</translation>
    </message>
    <message>
        <source>Load Motion Path</source>
        <translation>Carica una Traiettoria di Movimento</translation>
    </message>
    <message>
        <source>Can&apos;t paste styles there</source>
        <translation>Non è possibile incollare uno stile in base alla selezione corrente.</translation>
    </message>
    <message>
        <source>Can&apos;t modify color #0</source>
        <translation>Non è possibile modificare lo stile #0.</translation>
    </message>
    <message>
        <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
        <translation>Gli stili tagliati/copiati sono di più di quelli selezionati. Incollare ugualmente aggiungendo gli stili?</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>For further information visit </source>
        <translation type="vanished">Per ulteriori informazioni visita </translation>
    </message>
    <message>
        <source>Fullpath:     </source>
        <translation>Percorso Completo:</translation>
    </message>
    <message>
        <source>File Type:    </source>
        <translation>Tipo di File:</translation>
    </message>
    <message>
        <source>Frames:       </source>
        <translation>Fotogrammi:</translation>
    </message>
    <message>
        <source>Owner:        </source>
        <translation>Proprietario:</translation>
    </message>
    <message>
        <source>Size:         </source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <source>Created:      </source>
        <translation>Creazione:</translation>
    </message>
    <message>
        <source>Modified:     </source>
        <translation>Modifica:</translation>
    </message>
    <message>
        <source>Last Access:  </source>
        <translation>Ultimo Accesso:</translation>
    </message>
    <message>
        <source>Image Size:   </source>
        <translation>Dimensione dell&apos;Immagine:</translation>
    </message>
    <message>
        <source>SaveBox:      </source>
        <translation>Savebox:</translation>
    </message>
    <message>
        <source>Bits/Sample:  </source>
        <translation>Bit per Canale:</translation>
    </message>
    <message>
        <source>Sample/Pixel: </source>
        <translation>Canali per Pixel:</translation>
    </message>
    <message>
        <source>Dpi:          </source>
        <translation>DPI:</translation>
    </message>
    <message>
        <source>Orientation:  </source>
        <translation>Orientazione:</translation>
    </message>
    <message>
        <source>Compression:  </source>
        <translation>Compressione:</translation>
    </message>
    <message>
        <source>Quality:      </source>
        <translation>Qualità:</translation>
    </message>
    <message>
        <source>Smoothing:    </source>
        <translation>Smoothing:</translation>
    </message>
    <message>
        <source>Codec:        </source>
        <translation>Codec:</translation>
    </message>
    <message>
        <source>Alpha Channel:</source>
        <translation>Canale Alfa:</translation>
    </message>
    <message>
        <source>Byte Ordering:</source>
        <translation>Ordine dei Byte:</translation>
    </message>
    <message>
        <source>H Pos:</source>
        <translation>H Pos:</translation>
    </message>
    <message>
        <source>Palette Pages:</source>
        <translation>Pagine della Palette:</translation>
    </message>
    <message>
        <source>Palette Styles:</source>
        <translation>Stili della Palette:</translation>
    </message>
    <message>
        <source>Camera Size:      </source>
        <translation>Dimensione di Camera:</translation>
    </message>
    <message>
        <source>Camera Dpi:       </source>
        <translation>DPI di Camera:</translation>
    </message>
    <message>
        <source>Number of Frames: </source>
        <translation>Numero di Fotogrammi:</translation>
    </message>
    <message>
        <source>Number of Levels: </source>
        <translation>Numero di Livelli:</translation>
    </message>
    <message>
        <source>Output Path:      </source>
        <translation>Percorso di Uscita:</translation>
    </message>
    <message>
        <source>Endianess:      </source>
        <translation>Endianess:</translation>
    </message>
    <message>
        <source>It is not possible to delete the style #</source>
        <translation>Non è possibile eliminare lo stile #</translation>
    </message>
    <message>
        <source>It is not possible to delete styles #0 and #1.</source>
        <translation>Non è possibile eliminare gli stili #0 e #1.</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;custom&gt;</translation>
    </message>
    <message>
        <source>It is not possible to find the %1 level.</source>
        <translation>Impossibile trovare il livello %1.</translation>
    </message>
    <message>
        <source>There was an error copying %1</source>
        <translation>Errore durante la copia di %1</translation>
    </message>
    <message>
        <source>It is not possible to find the level %1</source>
        <translation>Impossibile trovare il livello %1</translation>
    </message>
    <message>
        <source>Length:       </source>
        <translation>Lunghezza:</translation>
    </message>
    <message>
        <source>Channels: </source>
        <translation>Canali:</translation>
    </message>
    <message>
        <source>Sample Rate: </source>
        <translation>Frequenza Campionamento:</translation>
    </message>
    <message>
        <source>Sample Size:      </source>
        <translation>Dimensione Campionamento:</translation>
    </message>
    <message>
        <source>The file %1 does not exist.</source>
        <translation>Il file %1 non esiste.</translation>
    </message>
    <message>
        <source>It is not possible to assing a shortcut with modifiers to the visualization commands.</source>
        <translation type="vanished">Non è possibile assegnare uno shortcut con modificatori ai comandi di visualizzazione.</translation>
    </message>
    <message>
        <source>It is not possible to save the motion path.</source>
        <translation>Non è possibile salvare la traiettoria.</translation>
    </message>
    <message>
        <source>It is not possible to load the motion path.</source>
        <translation>Non è possibile caricare la traiettoria.</translation>
    </message>
    <message>
        <source>Toonz 7.1</source>
        <translation type="vanished">Toonz 7.1</translation>
    </message>
    <message>
        <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
        <translation>Il nome del file non può essere vuoto o contenere uno dei seguenti caratteri:
\ / : * ? &quot; |</translation>
    </message>
    <message>
        <source>The source image seems not suitable for this kind of conversion</source>
        <translation>L&apos;immagine sorgente non sembra adatta per questo tipo di conversione</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Deletion of Lines and Areas from raster-based levels is not undoable.
Are you sure?</source>
        <translation></translation>
    </message>
    <message>
        <source>Deleting &quot;%1&quot;.
Are you sure?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Elimina</translation>
    </message>
    <message>
        <source>Paste Style  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Style  from Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Style  from Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>  to Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color &amp;&amp; Name%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Name%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blend Colors  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Link  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Color from Studio Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Object  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Keyframe  at Frame : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Keyframe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Style   Palette : %1  Style#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 -&gt; %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 : Linear ON</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 : Linear OFF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 Key : %2  Frame %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Reference  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is not possible to assign a shortcut with modifiers to the visualization commands.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_textureShader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to link simple shader: %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get attribute location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get uniform location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Open 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
It should start with &quot;3DMESH&quot; keyword.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Frame: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>VectorBrushStyleChooserPage</comment>
        <translation type="unfinished">Colore Piatto</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>MyPaintBrushStyleChooserPage</comment>
        <translation type="unfinished">Colore Piatto</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>SpecialStyleChooserPage</comment>
        <translation type="unfinished">Colore Piatto</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>That is a reserved file name and cannot be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are no unused styles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and %1 more styles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erasing unused styles with following indices. Are you sure?

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click &amp; Drag Palette into Studio Palette</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>RgbLinkButtons</name>
    <message>
        <source>Copy RGB : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap %1 and %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicName</name>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Elimina</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicViewer</name>
    <message>
        <source>&amp;Fit to Window</source>
        <translation>&amp;Adattare alla Finestra</translation>
    </message>
    <message>
        <source>&amp;Focus on Current</source>
        <translation>&amp;Centrare sul Nodo Corrente</translation>
    </message>
    <message>
        <source>&amp;Reorder Nodes</source>
        <translation>&amp;Riordinare i Nodi</translation>
    </message>
    <message>
        <source>&amp;Reset Size</source>
        <translation>&amp;Ripristinare la Dimensione</translation>
    </message>
    <message>
        <source>&amp;Minimize Nodes</source>
        <translation>&amp;Minimizzare i Nodi</translation>
    </message>
    <message>
        <source>&amp;Maximize Nodes</source>
        <translation>&amp;Massimizzare i Nodi</translation>
    </message>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>&amp;Nuova Reggetta</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>&amp;Nuova Camera</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>&amp;Nuova Traiettoria di Movimento</translation>
    </message>
    <message>
        <source>&amp;Schematic Toggle</source>
        <translation type="vanished">&amp;Diagramma Effetti/Scena</translation>
    </message>
    <message>
        <source>&amp;Toggle node icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Selection Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Hand Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Switch output port display mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicWindowEditor</name>
    <message>
        <source>&amp;Close Editor</source>
        <translation>&amp;Chiudi il Modificatore</translation>
    </message>
</context>
<context>
    <name>SimilarShapeSegmentPage</name>
    <message>
        <source>Reference Curve:</source>
        <translation>Curva di Riferimento:</translation>
    </message>
    <message>
        <source>Frame Offset:</source>
        <translation>Fotogrammi di Sfalsamento:</translation>
    </message>
    <message>
        <source>There is a syntax error in the definition of the interpolation.</source>
        <translation>Errore di sintassi nella definizione dell&apos;interpolazione.</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>C&apos;è un riferimento circolare nella definizione dell&apos;interpolazione.</translation>
    </message>
</context>
<context>
    <name>SpecialStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Colore Piatto</translation>
    </message>
</context>
<context>
    <name>SpeedInOutSegmentPage</name>
    <message>
        <source>Speed in:</source>
        <translation type="vanished">Speed in:</translation>
    </message>
    <message>
        <source>Speed out:</source>
        <translation type="vanished">Speed Out:</translation>
    </message>
    <message>
        <source>First Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Handle:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>---</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SplinePainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>&amp;Save Motion Path...</source>
        <translation>&amp;Salva la Traiettoria di Movimento...</translation>
    </message>
    <message>
        <source>&amp;Load Motion Path...</source>
        <translation>&amp;Carica la Traiettoria di Movimento...</translation>
    </message>
</context>
<context>
    <name>StageSchematicNode</name>
    <message>
        <source>Toggle Autorotate Along Motion Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Link Motion Path to Control Points</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StageSchematicScene</name>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>&amp;Nuova Reggetta</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>&amp;Nuova Traiettoria di Movimento</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>&amp;Nuova Camera</translation>
    </message>
</context>
<context>
    <name>StudioPaletteTreeViewer</name>
    <message>
        <source>This folder is not empty. Delete anyway?</source>
        <translation>Questo folder non è vuota. Lo vuoi cancellare lo stesso?</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>Nuova Palette</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nuova Cartella</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Elimina la Cartella</translation>
    </message>
    <message>
        <source>Load into Current Palette</source>
        <translation>Carica nella Palette Corrente</translation>
    </message>
    <message>
        <source>Merge to Current Palette</source>
        <translation>Unisci alla Palette Corrente</translation>
    </message>
    <message>
        <source>Replace with Current Palette</source>
        <translation>Rimpiazza con la Palette Corrente</translation>
    </message>
    <message>
        <source>Delete Palette</source>
        <translation>Elimina la Palette</translation>
    </message>
    <message>
        <source>Search for Palettes</source>
        <translation>Ricerca le Palette</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Adatta il Livello Corrente a questa Palette</translation>
    </message>
    <message>
        <source>Convert to Studio Palette and Overwrite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the palette &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the selected palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move %1 to &quot;%2&quot;. Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <source>The current palette %1
in the studio palette has been modified. Do you want to save your changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="unfinished">Scarta</translation>
    </message>
    <message>
        <source>Convert %1 to Studio Palette and Overwrite. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">No</translation>
    </message>
    <message>
        <source>Replacing all selected palettes with the palette &quot;%1&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing the palette &quot;%1&quot; with the palette &quot;%2&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StudioPaletteViewer</name>
    <message>
        <source>&amp;New Folder</source>
        <translation type="vanished">&amp;Nuova Cartella</translation>
    </message>
    <message>
        <source>&amp;New Palette</source>
        <translation type="vanished">&amp;Nuova Palette</translation>
    </message>
    <message>
        <source>&amp;Search for Palettes</source>
        <translation type="vanished">&amp;Ricerca le Palette</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">&amp;Elimina</translation>
    </message>
</context>
<context>
    <name>StyleEditor</name>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Apply changes to current style</source>
        <translation>Applica i cambiamenti allo stile corrente</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Automatically update style changes</source>
        <translation>Aggiorna automaticamente i cambiamenti dello stile</translation>
    </message>
    <message>
        <source>Return To Previous Style</source>
        <translation>Torna allo Stile Precedente</translation>
    </message>
    <message>
        <source>Current Style</source>
        <translation>Stile Corrente</translation>
    </message>
    <message>
        <source>Plain</source>
        <translation type="vanished">Piatto</translation>
    </message>
    <message>
        <source>Texture</source>
        <translation>Trama</translation>
    </message>
    <message>
        <source>Special</source>
        <translation type="vanished">Speciale</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="vanished">Personalizzato</translation>
    </message>
    <message>
        <source>Vector Brush</source>
        <translation>Pennello Vettoriale</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide parts of the Color Page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style Editor - No Valid Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wheel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="unfinished">Palette</translation>
    </message>
    <message>
        <source>Cleanup </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Studio </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative colored + Triangle handle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Absolute colored + Line handle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slider Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex Color Names...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::ColorChannelControl</name>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::SettingsPage</name>
    <message>
        <source>Autopaint for Lines</source>
        <translation>Colorazione Automatica per le Linee</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleNameEditor</name>
    <message>
        <source>Name Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annulla</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="obsolete">Applica</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Editor: # %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply and Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy Inputs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SwatchViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TMessageViewer</name>
    <message>
        <source>Errors</source>
        <translation>Errori</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Avvertimenti</translation>
    </message>
    <message>
        <source>Infos</source>
        <translation type="vanished">Informazioni</translation>
    </message>
    <message>
        <source> Clear </source>
        <translation>Pulire</translation>
    </message>
    <message>
        <source>Display:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TablePainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>&amp;Ripristina il centro</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">È possibile caricare solo i file TNZBAT.</translation>
    </message>
</context>
<context>
    <name>VectorBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Colore Piatto</translation>
    </message>
</context>
<context>
    <name>WordButton</name>
    <message>
        <source>Remove %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
